@@ -10,6 +10,10 @@ import logging
 from typing import Optional, Union, Literal
 
 import pandas as pd
+from psycop_feature_generation.loaders.filters.diabetes_filters import (
+    keep_rows_where_diag_matches_t2d_diag,
+    keep_rows_where_diag_matches_t1d_diag,
+)
 
 from psycop_feature_generation.loaders.raw.utils import load_from_codes
 from psycop_feature_generation.utils import data_loaders
@@ -24,6 +28,7 @@ def from_contacts(
     wildcard_icd_code: Optional[bool] = False,
     shak_location_col: Optional[str] = None,
     shak_code: Optional[int] = None,
+    keep_code_col: Optional[bool] = False,
     shak_sql_operator: Optional[str] = None,
     timestamp_purpose: Optional[Literal["predictor", "outcome"]] = "predictor",
 ) -> pd.DataFrame:
@@ -38,6 +43,7 @@ def from_contacts(
         wildcard_icd_code (bool, optional): Whether to match on icd_code*. Defaults to False.
         shak_location_col (str, optional): Name of column containing shak code. Defaults to None. For diagnosis loaders, this column is "shakkode_ansvarlig". Combine with shak_code and shak_sql_operator.
         shak_code (int, optional): Shak code indicating where to keep/not keep visits from (e.g. 6600). Defaults to None.
+        keep_code_col (bool, optional): Whether to keep the code column. Defaults to False.
         shak_sql_operator (str, optional): Operator indicating how to filter shak_code, e.g. "!= 6600" or "= 6600". Defaults to None.
         timestamp_purpose (Literal[str], optional): The intended use of the loader. If used as a predictor, the timestamp should be set to the contact end time, in order to avoid data leakage from future
             events. If used a an outcome, the timestamp should be set as the contact start time, in order to avoid inflation of model performance.
@@ -80,6 +86,7 @@ def from_contacts(
         load_diagnoses=True,
         shak_location_col=shak_location_col,
         shak_code=shak_code,
+        keep_code_col=keep_code_col,
         shak_sql_operator=shak_sql_operator,
     )
 
@@ -227,6 +234,86 @@ def copd(
     )
 
 
+@data_loaders.register("type_2_diabetes")
+def type_2_diabetes(
+    n_rows: Optional[int] = None,
+    shak_location_col: Optional[str] = None,
+    shak_code: Optional[int] = None,
+    shak_sql_operator: Optional[str] = None,
+    timestamp_purpose: Optional[Literal["predictor", "outcome"]] = "predictor",
+) -> pd.DataFrame:
+    df = from_contacts(
+        icd_code=[
+            "E1",
+            "E16",
+            "O24",
+            "T383A",
+            "M142",
+            "G590",
+            "G632",
+            "H280",
+            "H334",
+            "H360",
+            "H450",
+            "N083",
+        ],
+        wildcard_icd_code=True,
+        n_rows=n_rows,
+        shak_location_col=shak_location_col,
+        shak_code=shak_code,
+        shak_sql_operator=shak_sql_operator,
+        timestamp_purpose=timestamp_purpose,
+        keep_code_col=True,
+    )
+
+    df_filtered = keep_rows_where_diag_matches_t2d_diag(
+        df=df,
+        col_name="diagnosegruppestreng",
+    )
+
+    return df_filtered
+
+
+@data_loaders.register("type_1_diabetes")
+def type_1_diabetes(
+    n_rows: Optional[int] = None,
+    shak_location_col: Optional[str] = None,
+    shak_code: Optional[int] = None,
+    shak_sql_operator: Optional[str] = None,
+    timestamp_purpose: Optional[Literal["predictor", "outcome"]] = "predictor",
+) -> pd.DataFrame:
+    df = from_contacts(
+        icd_code=[
+            "E1",
+            "E16",
+            "O24",
+            "T383A",
+            "M142",
+            "G590",
+            "G632",
+            "H280",
+            "H334",
+            "H360",
+            "H450",
+            "N083",
+        ],
+        wildcard_icd_code=True,
+        n_rows=n_rows,
+        shak_location_col=shak_location_col,
+        shak_code=shak_code,
+        shak_sql_operator=shak_sql_operator,
+        timestamp_purpose=timestamp_purpose,
+        keep_code_col=True,
+    )
+
+    df_filtered = keep_rows_where_diag_matches_t1d_diag(
+        df=df,
+        col_name="diagnosegruppestreng",
+    )
+
+    return df_filtered
+
+
 # Psychiatric diagnoses
 # data loaders for all diagnoses in the f0-chapter (organic mental disorders)
 @data_loaders.register("f0_disorders")
