@@ -6,7 +6,7 @@ utilities. If this file grows, consider splitting it up.
 import os
 from collections.abc import Hashable
 from pathlib import Path
-from typing import Any, Optional, Union
+from typing import Any, Optional
 
 import catalogue
 import pandas as pd
@@ -14,13 +14,7 @@ import pandas as pd
 data_loaders = catalogue.create("timeseriesflattener", "data_loaders")
 
 SHARED_RESOURCES_PATH = Path(r"E:\shared_resources")
-FEATURE_SETS_PATH = SHARED_RESOURCES_PATH / "feature_sets"
-OUTCOME_DATA_PATH = SHARED_RESOURCES_PATH / "outcome_data"
-RAW_DATA_VALIDATION_PATH = SHARED_RESOURCES_PATH / "raw_data_validation"
-FEATURIZERS_PATH = SHARED_RESOURCES_PATH / "featurizers"
-MODEL_PREDICTIONS_PATH = SHARED_RESOURCES_PATH / "model_predictions"
-PROJECT_ROOT = Path(__file__).resolve().parents[2]
-N_WORKERS = 30
+RELATIVE_PROJECT_ROOT = Path(__file__).resolve().parents[2]
 
 
 def format_dict_for_printing(d: dict) -> str:
